@@ -34,7 +34,7 @@ using MonoDevelop.Database.Sql;
 using MonoDevelop.Database.Components;
 using MonoDevelop.Database.Designer;
 using MonoDevelop.Core;
-using MonoDevelop.Core.Gui;
+using MonoDevelop.Ide;
 using MonoDevelop.Ide.Gui.Pads;
 using MonoDevelop.Components.Commands;
 using MonoDevelop.Ide.Gui.Components;
@@ -68,10 +68,10 @@ namespace MonoDevelop.Database.ConnectionManager
 			return AddinCatalog.GetString ("Tables");
 		}
 		
-		public override void BuildNode (ITreeBuilder treeBuilder, object dataObject, ref string label, ref Gdk.Pixbuf icon, ref Gdk.Pixbuf closedIcon)
+		public override void BuildNode (ITreeBuilder treeBuilder, object dataObject, NodeInfo nodeInfo)
 		{
-			label = AddinCatalog.GetString ("Tables");
-			icon = Context.GetIcon ("md-db-tables");
+			nodeInfo.Label = AddinCatalog.GetString ("Tables");
+			nodeInfo.Icon = Context.GetIcon ("md-db-tables");
 			BaseNode node = (BaseNode) dataObject;
 			node.RefreshEvent += RefreshHandler;
 		}
