@@ -66,10 +66,10 @@ namespace MonoDevelop.Database.ConnectionManager
 			return AddinCatalog.GetString ("Users");
 		}
 		
-		public override void BuildNode (ITreeBuilder treeBuilder, object dataObject, ref string label, ref Gdk.Pixbuf icon, ref Gdk.Pixbuf closedIcon)
+		public override void BuildNode (ITreeBuilder treeBuilder, object dataObject, NodeInfo nodeInfo)
 		{
-			label = AddinCatalog.GetString ("Users");
-			icon = Context.GetIcon ("md-db-users");
+			nodeInfo.Label = AddinCatalog.GetString ("Users");
+			nodeInfo.Icon = Context.GetIcon ("md-db-users");
 			
 			BaseNode node = (BaseNode) dataObject;
 			RefreshHandler += new EventHandler(OnRefreshEvent);
